#define MOZ_SOURCE_STAMP c3e447e07077412b9cfaacb2ea91974655ed753b
#define MOZ_SOURCE_REPO https://hg.mozilla.org/releases/mozilla-esr52
#define MOZ_SOURCE_URL https://hg.mozilla.org/releases/mozilla-esr52/rev/c3e447e07077412b9cfaacb2ea91974655ed753b
