/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM ../../../dist/idl/nsIFormatConverter.idl
 */

#ifndef __gen_nsIFormatConverter_h__
#define __gen_nsIFormatConverter_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIArray_h__
#include "nsIArray.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIFormatConverter */
#define NS_IFORMATCONVERTER_IID_STR "948a0023-e3a7-11d2-96cf-0060b0fb9956"

#define NS_IFORMATCONVERTER_IID \
  {0x948a0023, 0xe3a7, 0x11d2, \
    { 0x96, 0xcf, 0x00, 0x60, 0xb0, 0xfb, 0x99, 0x56 }}

class NS_NO_VTABLE nsIFormatConverter : public nsISupports {
 public:

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IFORMATCONVERTER_IID)

  /* nsIArray getInputDataFlavors (); */
  NS_IMETHOD GetInputDataFlavors(nsIArray * *_retval) = 0;

  /* nsIArray getOutputDataFlavors (); */
  NS_IMETHOD GetOutputDataFlavors(nsIArray * *_retval) = 0;

  /* boolean canConvert (in string aFromDataFlavor, in string aToDataFlavor); */
  NS_IMETHOD CanConvert(const char * aFromDataFlavor, const char * aToDataFlavor, bool *_retval) = 0;

  /* void convert (in string aFromDataFlavor, in nsISupports aFromData, in unsigned long aDataLen, in string aToDataFlavor, out nsISupports aToData, out unsigned long aDataToLen); */
  NS_IMETHOD Convert(const char * aFromDataFlavor, nsISupports *aFromData, uint32_t aDataLen, const char * aToDataFlavor, nsISupports * *aToData, uint32_t *aDataToLen) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIFormatConverter, NS_IFORMATCONVERTER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIFORMATCONVERTER \
  NS_IMETHOD GetInputDataFlavors(nsIArray * *_retval) override; \
  NS_IMETHOD GetOutputDataFlavors(nsIArray * *_retval) override; \
  NS_IMETHOD CanConvert(const char * aFromDataFlavor, const char * aToDataFlavor, bool *_retval) override; \
  NS_IMETHOD Convert(const char * aFromDataFlavor, nsISupports *aFromData, uint32_t aDataLen, const char * aToDataFlavor, nsISupports * *aToData, uint32_t *aDataToLen) override; 

/* Use this macro when declaring the members of this interface when the
   class doesn't implement the interface. This is useful for forwarding. */
#define NS_DECL_NON_VIRTUAL_NSIFORMATCONVERTER \
  NS_METHOD GetInputDataFlavors(nsIArray * *_retval); \
  NS_METHOD GetOutputDataFlavors(nsIArray * *_retval); \
  NS_METHOD CanConvert(const char * aFromDataFlavor, const char * aToDataFlavor, bool *_retval); \
  NS_METHOD Convert(const char * aFromDataFlavor, nsISupports *aFromData, uint32_t aDataLen, const char * aToDataFlavor, nsISupports * *aToData, uint32_t *aDataToLen); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIFORMATCONVERTER(_to) \
  NS_IMETHOD GetInputDataFlavors(nsIArray * *_retval) override { return _to GetInputDataFlavors(_retval); } \
  NS_IMETHOD GetOutputDataFlavors(nsIArray * *_retval) override { return _to GetOutputDataFlavors(_retval); } \
  NS_IMETHOD CanConvert(const char * aFromDataFlavor, const char * aToDataFlavor, bool *_retval) override { return _to CanConvert(aFromDataFlavor, aToDataFlavor, _retval); } \
  NS_IMETHOD Convert(const char * aFromDataFlavor, nsISupports *aFromData, uint32_t aDataLen, const char * aToDataFlavor, nsISupports * *aToData, uint32_t *aDataToLen) override { return _to Convert(aFromDataFlavor, aFromData, aDataLen, aToDataFlavor, aToData, aDataToLen); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIFORMATCONVERTER(_to) \
  NS_IMETHOD GetInputDataFlavors(nsIArray * *_retval) override { return !_to ? NS_ERROR_NULL_POINTER : _to->GetInputDataFlavors(_retval); } \
  NS_IMETHOD GetOutputDataFlavors(nsIArray * *_retval) override { return !_to ? NS_ERROR_NULL_POINTER : _to->GetOutputDataFlavors(_retval); } \
  NS_IMETHOD CanConvert(const char * aFromDataFlavor, const char * aToDataFlavor, bool *_retval) override { return !_to ? NS_ERROR_NULL_POINTER : _to->CanConvert(aFromDataFlavor, aToDataFlavor, _retval); } \
  NS_IMETHOD Convert(const char * aFromDataFlavor, nsISupports *aFromData, uint32_t aDataLen, const char * aToDataFlavor, nsISupports * *aToData, uint32_t *aDataToLen) override { return !_to ? NS_ERROR_NULL_POINTER : _to->Convert(aFromDataFlavor, aFromData, aDataLen, aToDataFlavor, aToData, aDataToLen); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsFormatConverter : public nsIFormatConverter
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIFORMATCONVERTER

  nsFormatConverter();

private:
  ~nsFormatConverter();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS(nsFormatConverter, nsIFormatConverter)

nsFormatConverter::nsFormatConverter()
{
  /* member initializers and constructor code */
}

nsFormatConverter::~nsFormatConverter()
{
  /* destructor code */
}

/* nsIArray getInputDataFlavors (); */
NS_IMETHODIMP nsFormatConverter::GetInputDataFlavors(nsIArray * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIArray getOutputDataFlavors (); */
NS_IMETHODIMP nsFormatConverter::GetOutputDataFlavors(nsIArray * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean canConvert (in string aFromDataFlavor, in string aToDataFlavor); */
NS_IMETHODIMP nsFormatConverter::CanConvert(const char * aFromDataFlavor, const char * aToDataFlavor, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void convert (in string aFromDataFlavor, in nsISupports aFromData, in unsigned long aDataLen, in string aToDataFlavor, out nsISupports aToData, out unsigned long aDataToLen); */
NS_IMETHODIMP nsFormatConverter::Convert(const char * aFromDataFlavor, nsISupports *aFromData, uint32_t aDataLen, const char * aToDataFlavor, nsISupports * *aToData, uint32_t *aDataToLen)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif



#endif /* __gen_nsIFormatConverter_h__ */
